[ssh]

enabled  = true

port     = ssh

filter   = sshd

logpath  = /var/log/auth.log

action   = hostsdeny[file=/etc/hosts.deny]

maxretry = 3

ignoreip = 127.0.0.1/8 {% if whitelisted_ips is defined %} {% for host in whitelisted_ips %} {{host}} {% endfor %} {% endif %}

findtime = 300

bantime  = -1
